package com.ruoyi.shipping.mapper;

import com.ruoyi.shipping.domain.TShipDeal;

import java.util.List;

/**
 * 凯和费用协议Mapper接口
 * 
 * @author ruoyi
 * @date 2022-01-07
 */
public interface TShipDealMapper 
{
    /**
     * 查询凯和费用协议
     * 
     * @param fId 凯和费用协议ID
     * @return 凯和费用协议
     */
    public TShipDeal selectTShipDealById(Long fId);

    /**
     * 查询凯和费用协议列表
     * 
     * @param tShipDeal 凯和费用协议
     * @return 凯和费用协议集合
     */
    public List<TShipDeal> selectTShipDealList(TShipDeal tShipDeal);

    /**
     * 新增凯和费用协议
     * 
     * @param tShipDeal 凯和费用协议
     * @return 结果
     */
    public int insertTShipDeal(TShipDeal tShipDeal);

    /**
     * 修改凯和费用协议
     * 
     * @param tShipDeal 凯和费用协议
     * @return 结果
     */
    public int updateTShipDeal(TShipDeal tShipDeal);

    /**
     * 删除凯和费用协议
     * 
     * @param fId 凯和费用协议ID
     * @return 结果
     */
    public int deleteTShipDealById(Long fId);

    /**
     * 批量删除凯和费用协议
     * 
     * @param fIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTShipDealByIds(Long[] fIds);
}
